@@ -18,7 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
-#include <qapplication.h>
+#include <QApplication>
+#include <QtNetwork>
+#include <QDir>
+#include <QDesktopWidget>
 
 #include "downloader.h"
 
@@ -35,5 +38,23 @@ int main(int argc, char *argv[])
 	Downloader downloader(url, version);
 	QObject::connect(&downloader, SIGNAL(finished()),
 		&app, SLOT(quit()));
+        downloader.show();
 	return app.exec();
+/*
+     Q_INIT_RESOURCE(ftp);
+ #ifdef Q_OS_SYMBIAN
+     // Change current directory from default private to c:\data
+     // in order that user can access the downloaded content
+     QDir::setCurrent( "c:\\data" );
+ #endif
+     QApplication app(argc, argv);
+     FtpWindow ftpWin;
+ #ifdef Q_OS_SYMBIAN
+     // Make application better looking and more usable on small screen
+     ftpWin.showMaximized();
+ #else
+     ftpWin.show();
+ #endif
+     return ftpWin.exec();
+*/
 }
