@@ -34,7 +34,7 @@
 #include <iostream>
 using namespace std;
 
-//default constructor
+//constructor
 AusearchProcess::AusearchProcess(QString ausearch_str_pp_str, QWidget *parent, const char *name): QDialog(parent, name)
 {
         //this will not freeze GUI
@@ -42,7 +42,7 @@ AusearchProcess::AusearchProcess(QString ausearch_str_pp_str, QWidget *parent, c
 
 	setCaption(tr("Ausearch Process"));
 	textEdit1 = new QTextEdit(this);
-	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
+        textEdit1->setStyleSheet("background-color: papayawhip");
         textEdit1->resize( 600, 100 );
 
 	closeButton = new QPushButton(tr("close"), this);
