@@ -21,21 +21,20 @@
 #ifndef AUTORELABEL_H
 #define AUTORELABEL_H
 
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qradiobutton.h>
-#include <q3buttongroup.h>
-#include <qdir.h> 
-#include <qregexp.h> 
-#include <qlabel.h> 
-#include <q3textedit.h>
-//Added by qt3to4:
-#include <Q3VBoxLayout>
-#include <Q3HBoxLayout>
+#include <QDialog>
+#include <QLayout>
+#include <QRadioButton>
+#include <Q3ButtonGroup>
+#include <QDir> 
+#include <QRegExp> 
+#include <QLabel> 
+#include <QTextEdit>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 
 
 class QLayout;
-class Q3TextEdit;
+class QTextEdit;
 class QLineEdit;
 class QPushButton;
 
@@ -59,16 +58,16 @@ private:
 	QPushButton *closeButton;
         QRadioButton *nowRadioButton;
         QRadioButton *nextbootRadioButton;
-	Q3TextEdit *textEdit1;
+	QTextEdit *textEdit1;
 
-	Q3VBoxLayout *mainLayout;
-	Q3VBoxLayout *upperLayout;
-	Q3VBoxLayout *underLayout;
-	Q3HBoxLayout *leftLayout;
-	Q3HBoxLayout *rightLayout;
-	Q3HBoxLayout *thirdLayout;
-	Q3VBoxLayout *middleLayout;
-	Q3HBoxLayout *footLayout;
+	QVBoxLayout *mainLayout;
+	QVBoxLayout *upperLayout;
+	QVBoxLayout *underLayout;
+	QHBoxLayout *leftLayout;
+	QHBoxLayout *rightLayout;
+	QHBoxLayout *thirdLayout;
+	QVBoxLayout *middleLayout;
+	QHBoxLayout *footLayout;
 
         QDir dir;
         QString path;
