@@ -32,7 +32,6 @@
 #include <fstream>
 
 #include "downloader.h"
-#include "downloader_process.h"
 
 #include <iostream>
 using namespace std;
@@ -41,6 +40,8 @@ using namespace std;
 //constructor
 Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 {
+	downloader_process_o = 0;
+
 	setCaption(tr("Download fedora"));
 
         optionButtonGroup = new Q3ButtonGroup(this);
@@ -115,7 +116,6 @@ Downloader::Downloader(QWidget *parent, const char *name): QDialog(parent, name)
 
 void Downloader::download_button_clicked()
 {
-	//QUrl url_for_fedora("ftp://mirrors.kernel.org");
 	if(usRadioButton->isChecked()){
                 url_for_fedora.setUrl("ftp://mirrors.kernel.org");
 		url_for_fedora.setPort(21);
@@ -202,46 +202,64 @@ void Downloader::download_button_clicked()
 		}
 	}
 
-	downloader_process_o = 0;
 	downloader_process_o = new DownloaderProcess(url_for_fedora, version);
+	//connect(closeButton, SIGNAL(clicked()), downloader_process_o, SLOT(close()));
 
-	connect(downloader_process_o, SIGNAL(downloader_process_close_button_clicked()), this, SLOT(close()));
-	connect(closeButton, SIGNAL(clicked()), downloader_process_o, SLOT(close()));
-	downloader_process_o->show();
-	downloader_process_o->raise();
-	downloader_process_o->setActiveWindow();
+	//connect(downloader_process_o, SIGNAL(downloader_process_close_button_clicked()), this, SLOT(close()));
+	//downloader_process_o->show();
+	//downloader_process_o->raise();
+	//downloader_process_o->setActiveWindow();
+	//
+	//downloader_base_process(url_for_fedora,version);
 }
-void Downloader::updateOutputTextEdit()
+void Downloader::downloader_base_process(QUrl& url_for_fedora, QString version)
 {
-	QByteArray data = process->readAllStandardError();
+	this->setEnabled(true);
+	//this->setEnabled(true);
+	process = new QProcess(this);
+	connect(process, SIGNAL(readyReadStandardOutput()),this,SLOT(readFromStdout()));
+	connect(process, SIGNAL(readyReadStandardError()),this,SLOT(updateOutputTextEdit()));
+	connect(process, SIGNAL(finished(int, QProcess::ExitStatus)),this,SLOT(processExited(int, QProcess::ExitStatus)));
+        QString url_str = "/usr/share/segatex/downloader_program " + url_for_fedora + " " + version;
+    	//process->start("/bin/bash", QStringList() << "-c" << "export LANG=C;ls -la");
+	process->start(url_str);
+	//process->start("/bin/bash", QStringList() << "-c" << "export LANG=C;" + url_str);
 }
 void Downloader::readFromStdout()
 {
 	QByteArray data = process->readAllStandardOutput();
+	//QString text = textEdit1->text() + QString(data);
+	//textEdit1->setText(text);
+}
+void Downloader::updateOutputTextEdit()
+{
+	QByteArray data = process->readAllStandardError();
+	//QString text = textEdit1->text() + QString(data);
+	//textEdit1->setText(text);
 }
 void Downloader::processExited(int exitCode, QProcess::ExitStatus exitStatus)
 {
 	if ( exitStatus == QProcess::CrashExit )
 	{
 		//QMessageBox::warning( this, tr("Error"), tr("Crashed") );
-		QMessageBox::warning(0, tr("Downloader Fedora"),
-				     tr("Downloader Fedora process crashed."));
-		return;
+		//textEdit1->append(tr("Error, Crashed !"));
+		//textEdit1->append(tr("\n"));
 	}
 	else if ( exitCode != 0 )
 	{
 		//QMessageBox::warning( this, tr("Error"), tr("Failed") );
-		QMessageBox::warning(0, tr("Downloader Fedora"),
-				     tr("Downloader Fedora process had an error."));
-		return;
+		//textEdit1->append(tr("Error, Failed !"));
+		//textEdit1->append(tr("\n"));
 	}
 	else
 	{
-		QMessageBox::warning(0, tr("Downloader Fedora"),
-				     tr("Downloader Fedora process was a success"));
+		//textEdit1->append(tr("Fedora downloader process ended!"));
+		//textEdit1->append(tr("\n"));
+		//textEdit1->append(tr("Please check iso and CHECKSUM file."));
+		//textEdit1->append(tr("\n"));
         }
 	delete process;
 	process = 0;
-	this->setEnabled(true);
+	//this->setEnabled(true);
 }
 
