@@ -56,6 +56,7 @@
 #include <QApplication>
 #include <QLabel>
 #include <QLayout>
+#include <QFtp>
 #include <QMenuBar>
 #include <QMessageBox>
 #include <QStatusBar>
@@ -179,10 +180,19 @@
 	createStatusBar();
 	updateMenus();
 	readSettings();
-	setWindowTitle(tr("segatex-8.630"));
+	setWindowTitle(tr("segatex-8.640"));
 	QPixmap myIcon1 = QPixmap(":/images/icon.png");
 	this->setIcon(myIcon1);
 }
+void MainWindow::about()
+{
+	QMessageBox::about(this, tr("About segatex"),
+		tr("<h2>segatex-8.640</h2>"
+		"<p>Copyright &copy; 2007-2014"
+		"<p>Shintaro Fujiwara."
+		"<p><a href=\"http://sourceforge.net/projects/segatex\">segatex</a> is a SELinux tool"
+		"<p><b>written with Qt</b>."));
+}
 void MainWindow::createMenus()
 {
 	fileMenu = menuBar()->addMenu(tr("&File"));
@@ -632,15 +642,6 @@ void MainWindow::paste()
 {
 	if (activeMdiChild())
 	activeMdiChild()->paste();
-}
-void MainWindow::about()
-{
-	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-8.630</h2>"
-		"<p>Copyright &copy; 2007-2014"
-		"<p>Shintaro Fujiwara."
-		"<p><a href=\"http://sourceforge.net/projects/segatex\">segatex</a> is a SELinux tool"
-		"<p><b>written with Qt</b>."));
 }
  void MainWindow::updateMenus()
  {
@@ -1074,10 +1075,9 @@ void MainWindow::downloader()
 void MainWindow::downloader_process()
 {
 	if(!downloader_process_o) {
-		QUrl url_for_fedora("ftp://mirrors.kernel.org");
-		url_for_fedora.setPort(21);
-                QString version="new";
-		downloader_process_o = new DownloaderProcess(url_for_fedora,version,this);
+                QUrl url_for_fedora;
+                QString version;
+	        downloader_process_o = new DownloaderProcess(url_for_fedora, version);
 	}
 	downloader_process_o->show();
 	downloader_process_o->raise();
@@ -1202,7 +1202,7 @@ void MainWindow::howtouse()
 		"<br />"
 		" You can add/delete Linux user."
 		"<br />"
-		" You can ftp download brand new Fedora iso files."
+		" You can ftp download Fedora iso files."
 		"<br />"
 		" You can analyze refpolicy."
 		"<br />"
