@@ -18,13 +18,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <q3process.h>
-//Added by qt3to4:
-#include <Q3TextStream>
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
+#include <QLayout>
+#include <QPushButton>
+#include <QTextStream>
 
 #include "segatex_audit2why_process.h"
 
@@ -36,7 +32,7 @@ using namespace std;
 //default constructor
 SegatexAudit2whyProcess::SegatexAudit2whyProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
-	textEdit1 = new Q3TextEdit(this);
+	textEdit1 = new QTextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(255,187,174));
 	closeButton = new QPushButton(tr("close"), this);
 	closeButton->setDefault(true);
@@ -45,14 +41,14 @@ SegatexAudit2whyProcess::SegatexAudit2whyProcess(QWidget *parent, const char *na
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close_button_clicked()));
 	//connect to checkboxes
 
-	Q3VBoxLayout *headLayout = new Q3VBoxLayout;
+	headLayout = new QVBoxLayout;
 	headLayout->addWidget(textEdit1);
 
-	Q3HBoxLayout *footLayout = new Q3HBoxLayout;
+	footLayout = new QHBoxLayout;
 	footLayout->addStretch(1);
 	footLayout->addWidget(closeButton);
 
-	Q3VBoxLayout *mainLayout = new Q3VBoxLayout(this);
+	mainLayout = new QVBoxLayout(this);
 	mainLayout->setMargin(11);
 	mainLayout->setSpacing(6);
 	mainLayout->addLayout(headLayout);
@@ -121,7 +117,7 @@ void SegatexAudit2whyProcess::readFromOutputFile()
 			//cout << "file_interface_name" << file_interface_name << endl;
 			QFile file( file_interface_name );
 			if ( file.open( QIODevice::ReadOnly ) ) {
-				Q3TextStream stream( &file );
+				QTextStream stream( &file );
 				////////////////////////////////////////////
 				while ( !stream.atEnd() ) {
 					line_analized = stream.readLine(); // line of text excluding '\n'
@@ -133,6 +129,6 @@ void SegatexAudit2whyProcess::readFromOutputFile()
 				//do nothing
 			}
 		}
-	textEdit1->setCursorPosition(0,0);
+	//textEdit1->setCursorPosition(0,0);
 }
 
