@@ -22,8 +22,10 @@
 #define SEGATEXAUDIT2WHYPROCESS_H
 
 #include <QDialog>
-#include <q3textedit.h>
-#include <qdir.h> 
+#include <QTextEdit>
+#include <QDir> 
+#include <QVBoxLayout> 
+#include <QHBoxLayout> 
 
 class SegatexAudit2whyProcess: public QDialog 
 {
@@ -42,7 +44,7 @@ private slots:
 public:
 private:
 	QPushButton *closeButton;
-	Q3TextEdit *textEdit1;
+	QTextEdit *textEdit1;
 
         QDir dir;
         QString path;
@@ -55,6 +57,9 @@ private:
 
         QStringList::Iterator it_d;
         QStringList files;
+        QVBoxLayout *headLayout;
+        QHBoxLayout *footLayout;
+        QVBoxLayout *mainLayout;
 
 };
 
