@@ -21,15 +21,15 @@
 #ifndef SEGATEXSTATE_H
 #define SEGATEXSTATE_H
 
-#include <qregexp.h>
-#include <q3textedit.h>
+#include <QRegExp>
+#include <QTextEdit>
 
 #include <selinux/selinux.h>
 #include <selinux/get_default_type.h>
 
 class QMessageBox;
 
-class SegatexState: public Q3TextEdit
+class SegatexState: public QTextEdit
 {
 	Q_OBJECT
 public:
