@@ -18,18 +18,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <q3process.h>
-#include <qradiobutton.h>
-#include <q3buttongroup.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-//Added by qt3to4:
-#include <Q3TextStream>
-#include <Q3HBoxLayout>
+#include <QLayout>
+#include <QPushButton>
+#include <QProcess>
+#include <QRadioButton>
+#include <QButtonGroup>
+#include <QLineEdit>
+#include <QTextEdit>
+#include <QTextStream>
 #include <QLabel>
-#include <Q3VBoxLayout>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -46,7 +43,7 @@ using namespace std;
 SemanageCoreLoginProcess::SemanageCoreLoginProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Semanage Login Process"));
-	textEdit1 = new Q3TextEdit(this);
+	textEdit1 = new QTextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
 
 	semanageEditLabel = new QLabel(tr("Add Unix user:"), this );
@@ -97,16 +94,16 @@ SemanageCoreLoginProcess::SemanageCoreLoginProcess(QWidget *parent, const char *
 	//set textEdit smanage such and such -l
 	semanage_core_base_login_process();
 
-	mainLayout = new Q3VBoxLayout(this);
+	mainLayout = new QVBoxLayout(this);
 	mainLayout->setMargin(11);
 
-	upperLayout = new Q3VBoxLayout;
+	upperLayout = new QVBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-	middleLayout = new Q3VBoxLayout;
-	leftLayout = new Q3HBoxLayout;
-	rightLayout = new Q3HBoxLayout;
-	thirdLayout = new Q3HBoxLayout;
+	middleLayout = new QVBoxLayout;
+	leftLayout = new QHBoxLayout;
+	rightLayout = new QHBoxLayout;
+	thirdLayout = new QHBoxLayout;
 	
 	leftLayout->addWidget(semanageEditLabel);
 	leftLayout->addWidget(semanageEditLineEdit);
@@ -130,7 +127,7 @@ SemanageCoreLoginProcess::SemanageCoreLoginProcess(QWidget *parent, const char *
 	middleLayout->addLayout(rightLayout);
 	middleLayout->addLayout(thirdLayout);
 
-	footLayout = new Q3HBoxLayout;
+	footLayout = new QHBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -364,7 +361,7 @@ void SemanageCoreLoginProcess::readFromOutputFile()
 			QRegExp rx_false("false");
 			QRegExp rx_sync("sync");
 			if ( file.open( QIODevice::ReadOnly ) ) {
-				Q3TextStream stream( &file );
+				QTextStream stream( &file );
 				////////////////////////////////////////////
 				int i,j,k,l,m,n;	
 				if(order_x == 1)
@@ -391,7 +388,7 @@ void SemanageCoreLoginProcess::readFromOutputFile()
 						textEdit1->append(line_analized);
 					}
 				}
-				textEdit1->setCursorPosition(0,0);
+				//textEdit1->setCursorPosition(0,0);
 				file.close();
 				order_x++;
 				++it_d;
