@@ -18,18 +18,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * */
 
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <q3process.h>
-#include <qradiobutton.h>
-#include <q3buttongroup.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-#include <q3process.h>
-//Added by qt3to4:
-#include <Q3TextStream>
-#include <Q3HBoxLayout>
-#include <Q3VBoxLayout>
+#include <QLayout>
+#include <QPushButton>
+#include <QProcess>
+#include <QRadioButton>
+#include <QButtonGroup>
+#include <QLineEdit>
+#include <QTextEdit>
+#include <QProcess>
+#include <QTextStream>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -47,7 +44,7 @@ using namespace std;
 SemanageCoreProcess::SemanageCoreProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Semanage Process"));
-	textEdit1 = new Q3TextEdit(this);
+	textEdit1 = new QTextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(200,254,100));
 	closeButton = new QPushButton(tr("close"), this);
 	//closing process button
@@ -57,13 +54,13 @@ SemanageCoreProcess::SemanageCoreProcess(QWidget *parent, const char *name): QDi
 	//set textEdit smanage such and such -l
 	semanage_core_base_process();
 
-	mainLayout = new Q3VBoxLayout(this);
+	mainLayout = new QVBoxLayout(this);
 	mainLayout->setMargin(11);
 
-	upperLayout = new Q3VBoxLayout;
+	upperLayout = new QVBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-	footLayout = new Q3HBoxLayout;
+	footLayout = new QHBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -287,7 +284,7 @@ void SemanageCoreProcess::readFromOutputFile()
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
 			if ( file.open( QIODevice::ReadOnly ) ) {
-				Q3TextStream stream( &file );
+				QTextStream stream( &file );
 				////////////////////////////////////////////
 				if(order_x == 1)
 					textEdit1->append("#########login list#########");
@@ -314,7 +311,7 @@ void SemanageCoreProcess::readFromOutputFile()
 					line_analized = stream.readLine(); // line of text excluding '\n'
 					textEdit1->append(line_analized);
 				}
-				textEdit1->setCursorPosition(0,0);
+				//textEdit1->setCursorPosition(0,0);
 				file.close();
 				order_x++;
 				++it_d;
