@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2013 Shintaro Fujiwara 
+ * Copyright (C) 2007-2014 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,16 +21,15 @@
 #ifndef SESEARCHPROCESS_H
 #define SESEARCHPROCESS_H
 
-#include <qdialog.h>
-#include <qlayout.h>
-#include <qdir.h> 
-#include <qlabel.h> 
-#include <q3textedit.h>
-#include <q3buttongroup.h>
-#include <qradiobutton.h>
-//Added by qt3to4:
-#include <Q3VBoxLayout>
-#include <Q3HBoxLayout>
+#include <QDialog>
+#include <QLayout>
+#include <QDir> 
+#include <QLabel> 
+#include <QTextEdit>
+#include <QButtonGroup>
+#include <QRadioButton>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 
 class SesearchProcess: public QDialog 
 {
@@ -46,11 +45,11 @@ private slots:
 public:
 private:
 	QPushButton *closeButton;
-	Q3TextEdit *textEdit1;
+	QTextEdit *textEdit1;
 
-	Q3VBoxLayout *mainLayout;
-	Q3VBoxLayout *upperLayout;
-	Q3HBoxLayout *footLayout;
+	QVBoxLayout *mainLayout;
+	QVBoxLayout *upperLayout;
+	QHBoxLayout *footLayout;
 
         QDir dir;
         QString path;
